Providers
=========

LinchPin has many default providers. This choose-your-own-adventure page takes you through the basics to ensure success for each.

.. toctree::
   :maxdepth: 1

   openstack
   libvirt
   aws
   gcloud
   beaker
   duffy
   ovirt
   openshift
   rackspace
   provider_external


